! Time-stamp: <fe8.zeus.fairmont.rdhpcs.noaa.gov:/home/Andy.Jacobson/TM5/proj/ctemis/branches/fires_GFED_CMS/src/emission_co2_fires__GFED_CMS.F90: 09 Jul 2015 (Thu) 03:21:54 UTC>

#define TRACEBACK write (gol,'("in ",a," (",a,", line",i5,")")') rname, __FILE__, __LINE__; call goErr
#define IF_NOTOK_RETURN(action) if (status/=0) then; TRACEBACK; action; return; end if
#define IF_ERROR_RETURN(action) if (status> 0) then; TRACEBACK; action; return; end if
#include "tm5.inc"

! Compute wildfire emissions of CO2 in mol m-2 s-1.  Positive is source to atmosphere.

module emission_co2_fires

  use GO,		only: gol, goErr, goPr, goLabel
  use Dims,		only: nregions, nlon360, nlat180
  use emission_common,	only: enkf_parms, field_1x1, EmisInputDir, co2_fires
  use emission_common,	only: nmembersloc
  use ReadFromFile_MDF,	only : ReadFromFile
  use MDF,		only : MDF_NETCDF

  implicit none

  character(len=*), parameter	:: mname = 'emission_co2_fires'

  private
  character(len=2048)		:: fires_prefix
  character(len=256)		:: fires_varname

  public	:: emission_co2_fires_init, emission_co2_fires_done, emission_co2_fires_calc

  ! use this to potentially override the EmisInputDir
  character(len=1024)	:: FiresInputDir

contains

  subroutine emission_co2_fires_init(status)

    use GO,		only: TrcFile, Init, Done, ReadRc
    use global_data,	only: rcfile
    use dims,		only: im,jm,nregions

    implicit none

    character(len=*), parameter	:: rname = mname//'/emission_co2_fires_init'

    integer			:: region, imr, jmr, n
    integer, intent(out)	:: status
    type(TrcFile)		:: rcF

    call Init( rcF, rcfile, status )
    IF_NOTOK_RETURN(status=1)
    call ReadRc( rcF, 'fires.input.dir', FiresInputDir ,status ,default=EmisInputDir)
    IF_ERROR_RETURN(status=1)
    call ReadRc( rcF, 'fires.fname.prefix', fires_prefix,status ,default=EmisInputDir)
    IF_ERROR_RETURN(status=1)
    call Done( rcF, status )
    IF_NOTOK_RETURN(status=1)

    write (gol,'("[emission_co2_fires_init]	fires input files to be read from """,a,""".")') trim(FiresInputDir)
    call goPr
    write (gol,'("[emission_co2_fires_init]	   from files with names like ",a,".YYYYMMDD.nc.")') trim(fires_prefix)
    call goPr

  end subroutine emission_co2_fires_init

  subroutine emission_co2_fires_calc(parms,co2_fires,flux_updated,parms_updated,status)

    use dims,			only : sec_month, idate, newday, sec_year, newsrun
    use emission_data,		only : chardate, flux_to_gridbox_per_month
    use go_string,		only : goNum2str
    use chem_param,		only : xmc

    implicit none

    character(len=*), parameter			:: rname = mname//'/emission_co2_fires_calc'

    ! parms actually not used here since we do not optimize FIRES emissions
    type(enkf_parms), dimension(:), intent(in)	:: parms

    type(field_1x1), dimension(:), intent(out)	:: co2_fires
    real*4,dimension(360,180,1)			:: temp_read
    integer, intent(out)			:: status
    logical, intent(out)			:: flux_updated
    logical, intent(in)				:: parms_updated

    character(len=10)				:: cdate
    integer					:: imember
    real					:: month2year


    flux_updated = .false.

    if(newday.or.newsrun) then

       flux_updated = .true.

       cdate=trim(goNum2str(idate(1),'(i4.4)'))//trim(goNum2str(idate(2),'(i2.2)'))//trim(goNum2str(idate(3),'(i2.2)'))

       ! units of biomass burning are molC m-2 s-1
       call ReadFromFile(fname=trim(FiresInputDir)//'/'//trim(fires_prefix)//'.'//trim(cdate)//'.nc',ftype=MDF_NETCDF,vname='fire',buffer=temp_read,lenient_typing=.TRUE.,status=status)
       IF_ERROR_RETURN(status=1)

       ! used for diagnostic output only
       month2year = sec_year/sec_month

       do imember=1,nmembersloc
          co2_fires(imember)%surf=12*temp_read(:,:,1)/1.0e3 ! from molC m-2 s-1 to kgC m-2 s-1

          call flux_to_gridbox_per_month(co2_fires(imember)%surf) ! convert from kgC m-2 s-1 to kgC 1x1_gridbox-1 month-1

          write (gol,'("[emission_co2_fires_calc]	member ",i4,": wildfire emission global integral ",f12.4," PgC/yr.")') imember,sum(co2_fires(imember)%surf)*1.0e-12*month2year
          call goPr

       end do

    endif ! newday or newsrun

  end subroutine emission_co2_fires_calc

  subroutine emission_co2_fires_done(status)

    use dims,		only: nregions

    implicit none

    integer, intent(out)			:: status

    character(len=*), parameter	:: rname = mname//'/emission_co2_fires_done'

    status=0
    return

  end subroutine emission_co2_fires_done


end module emission_co2_fires

